planning
0.1.0
All Items
Structs
Traits
Functions
Crate
planning
source
·
[
−
]
Structs

Agent
An independent stateful agent capable of selecting from a list of goals.
Traits

Action
Goal
Functions

hash_
map_
diff
plan
Returns a sequence of actions to reach the goal while minimizing cost, if possible.